Overview — amplpower 0.0.0 documentation

# Overview

docs |
tests |
package |

AMPL package for power systems

- Free software: MIT license

## Installation

    pip install amplpower

You can also install the in-development version with:

    pip install https://github.com/salvapineda/amplpower/archive/main.zip

## Documentation

https://amplpower.readthedocs.io/

## Development

To run all the tests run:

    tox

Note, to combine the coverage data from all the tox environments run:

Windows |
    set PYTEST_ADDOPTS=--cov-append
    tox
Other |
    PYTEST_ADDOPTS=--cov-append tox